package com.ruoyi.school.paper.controller;

import java.util.List;
import java.util.Arrays;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.school.paper.domain.vo.DbBannerVo;
import com.ruoyi.school.paper.domain.bo.DbBannerBo;
import com.ruoyi.school.paper.service.IDbBannerService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 轮播图
 *
 * @author ruoyi
 * @date 2023.07.24
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/school-paper/banner")
public class DbBannerController extends BaseController {

    private final IDbBannerService iDbBannerService;

    /**
     * 查询轮播图列表
     */
    @SaCheckPermission("school.paper:banner:list")
    @GetMapping("/list")
    public TableDataInfo<DbBannerVo> list(DbBannerBo bo, PageQuery pageQuery) {
        return iDbBannerService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出轮播图列表
     */
    @SaCheckPermission("school.paper:banner:export")
    @Log(title = "轮播图", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(DbBannerBo bo, HttpServletResponse response) {
        List<DbBannerVo> list = iDbBannerService.queryList(bo);
        ExcelUtil.exportExcel(list, "轮播图", DbBannerVo.class, response);
    }

    /**
     * 获取轮播图详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("school.paper:banner:query")
    @GetMapping("/{id}")
    public R<DbBannerVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable Long id) {
        return R.ok(iDbBannerService.queryById(id));
    }

    /**
     * 新增轮播图
     */
    @SaCheckPermission("school.paper:banner:add")
    @Log(title = "轮播图", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody DbBannerBo bo) {
        return toAjax(iDbBannerService.insertByBo(bo));
    }

    /**
     * 修改轮播图
     */
    @SaCheckPermission("school.paper:banner:edit")
    @Log(title = "轮播图", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody DbBannerBo bo) {
        return toAjax(iDbBannerService.updateByBo(bo));
    }

    /**
     * 删除轮播图
     *
     * @param ids 主键串
     */
    @SaCheckPermission("school.paper:banner:remove")
    @Log(title = "轮播图", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable Long[] ids) {
        return toAjax(iDbBannerService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
